==> prestashop_1.4.0.7.zip: prestashop/modules/shopImporter/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{shopImporter}prestashop>shopImporter_d714c742b360a8ecbb124c15e9a391a1'] = 'Importateur de boutique';
$_MODULE['<{shopImporter}prestashop>shopImporter_b51e3d770566c831063a131631e494c2'] = 'Ce module permet d\'importer d\'un autre système dans prestashop';
$_MODULE['<{shopImporter}prestashop>shopImporter_4994a8ffeba4ac3140beb89e8d41f174'] = 'Langue';
$_MODULE['<{shopImporter}prestashop>shopImporter_a9db6adcdafc85c5830439401fd866f6'] = 'Importation des langues';
$_MODULE['<{shopImporter}prestashop>shopImporter_5c9ada346bd1c8b1adae50aec0e7437c'] = 'Les nouvelles langues seront automatiquement ajouter les traductions!';
$_MODULE['<{shopImporter}prestashop>shopImporter_386c339d37e737a436499d423a77df0c'] = 'Devise';
$_MODULE['<{shopImporter}prestashop>shopImporter_4234c64201820401dfa04eeb449c1bbc'] = 'Importation des Devises';
$_MODULE['<{shopImporter}prestashop>shopImporter_b3ff996fe5c77610359114835baf9b38'] = 'Zone';
$_MODULE['<{shopImporter}prestashop>shopImporter_21d250d17e35e3e02db9f1a618bad913'] = 'Importation des Zones';
$_MODULE['<{shopImporter}prestashop>shopImporter_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{shopImporter}prestashop>shopImporter_13eedcf49d68ce49274db71e63a7aa3d'] = 'Importation des Pays';
$_MODULE['<{shopImporter}prestashop>shopImporter_46a2a41cc6e552044816a2d04634545d'] = 'Etat';
$_MODULE['<{shopImporter}prestashop>shopImporter_118421de3201927a23bf921057e69c4a'] = 'Importation des Etats';
$_MODULE['<{shopImporter}prestashop>shopImporter_03937134cedab9078be39a77ee3a48a0'] = 'Groupe';
$_MODULE['<{shopImporter}prestashop>shopImporter_65ac19ad248219902394739bda0cef62'] = 'Importation des Groupes';
$_MODULE['<{shopImporter}prestashop>shopImporter_ce26601dac0dea138b7295f02b7620a7'] = 'Client';
$_MODULE['<{shopImporter}prestashop>shopImporter_22c34564e80ce8adab6a235061d277f4'] = 'Importation des Clients';
$_MODULE['<{shopImporter}prestashop>shopImporter_dd7bf230fde8d4836917806aff6a6b27'] = 'Adresse';
$_MODULE['<{shopImporter}prestashop>shopImporter_77497d022aeb4cdd78ec394ca8d223b4'] = 'Importation des Adresses';
$_MODULE['<{shopImporter}prestashop>shopImporter_a240fa27925a635b08dc28c9e4f9216d'] = 'Commande';
$_MODULE['<{shopImporter}prestashop>shopImporter_3b7e768ebab2171baa41d5ea13017b02'] = 'Importation des Commandes';
$_MODULE['<{shopImporter}prestashop>shopImporter_c0bd7654d5b278e65f21cf4e9153fdb4'] = 'Fabricant';
$_MODULE['<{shopImporter}prestashop>shopImporter_ed4cbbbeb3d575ccfeb405ae5c5c4d43'] = 'Importation des Fabricants';
$_MODULE['<{shopImporter}prestashop>shopImporter_ec136b444eede3bc85639fac0dd06229'] = 'Fournisseur';
$_MODULE['<{shopImporter}prestashop>shopImporter_0ae5f9c75e6a7460ec31e33201576bd9'] = 'Importation des Fournisseurs';
$_MODULE['<{shopImporter}prestashop>shopImporter_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Categorie';
$_MODULE['<{shopImporter}prestashop>shopImporter_1db7ae20c24e257b6f1a7def365da1ad'] = 'Importation des Categories';
$_MODULE['<{shopImporter}prestashop>shopImporter_deb10517653c255364175796ace3553f'] = 'Produit';
$_MODULE['<{shopImporter}prestashop>shopImporter_4bfc4a7632bae0877b798dbd9efc4f70'] = 'Importation des Produits';
$_MODULE['<{shopImporter}prestashop>shopImporter_d6dd5b5b36770c26db3e12c02c2a37db'] = 'Déclinaisons de Produits';
$_MODULE['<{shopImporter}prestashop>shopImporter_58e2fcec5e04716c627b3e8b9d2955b1'] = 'Importation des Déclinaisons de Produits';
$_MODULE['<{shopImporter}prestashop>shopImporter_32a6deec3cca312a54d6b8769c9b8dd7'] = 'n\'est pas disponible dans ce module';
$_MODULE['<{shopImporter}prestashop>shopImporter_1e411d25230ba738b9ae583bcb9b0b57'] = 'Connexion à la base OK';
$_MODULE['<{shopImporter}prestashop>shopImporter_3596c777cbc8b72d678f34daabc9148b'] = 'Voir les erreurs';
$_MODULE['<{shopImporter}prestashop>shopImporter_89a399eee52b2a6daaea92eba3e14cad'] = 'Lancer le test d\'import';
$_MODULE['<{shopImporter}prestashop>shopImporter_72d6d7a1885885bb55a565fd1070581a'] = 'Importer';
$_MODULE['<{shopImporter}prestashop>shopImporter_e08d2dad1fcd8a0d89e242939b2475bb'] = 'Merci de corriger les erreurs avant de continuer';
$_MODULE['<{shopImporter}prestashop>shopImporter_a4376f284662da6f3997514ca74597c9'] = 'L\'import est terminé';
$_MODULE['<{shopImporter}prestashop>shopImporter_596403b61367ca30d6de75812275f9cd'] = 'Suppression des données';
$_MODULE['<{shopImporter}prestashop>shopImporter_edc186cbc5cc897a79312880ec16c621'] = 'Merci de choisir quelquechose à importer';
$_MODULE['<{shopImporter}prestashop>shopImporter_81b33153f65252001fe132d74b658fbe'] = 'Importer à partir d\'un autre système ';
$_MODULE['<{shopImporter}prestashop>shopImporter_dd4c0c798ebbf8c6e15dcba8632f558d'] = 'Avant de commencer l\'importation merci de sauvegarder votre base de données.';
$_MODULE['<{shopImporter}prestashop>shopImporter_60474e812295a5adc371de63dc62a164'] = 'Cliquez ici pour sauvegarder';
$_MODULE['<{shopImporter}prestashop>shopImporter_05f4be265d59ea66f3a1fb12ba103583'] = 'Choisissez votre module d\'importation  ';
$_MODULE['<{shopImporter}prestashop>shopImporter_961f2247a2070bedff9f9cd8d64e2650'] = 'Choisir';
$_MODULE['<{shopImporter}prestashop>shopImporter_9aa1b03934893d7134a660af4204f2a9'] = 'Serveur';
$_MODULE['<{shopImporter}prestashop>shopImporter_8f9bfe9d1345237cb3b2b205864da075'] = 'Utilisateur';
$_MODULE['<{shopImporter}prestashop>shopImporter_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{shopImporter}prestashop>shopImporter_e307db07b3975fef922a80d07455ee5e'] = 'Base de données';
$_MODULE['<{shopImporter}prestashop>shopImporter_dac130bdd2c5492a8108a4145bd9f04a'] = 'Prefix de base de données';
$_MODULE['<{shopImporter}prestashop>shopImporter_2bb4cbbf4c51025867d47131e79ad05f'] = 'Étape suivante';
$_MODULE['<{shopImporter}prestashop>shopImporter_72dd98a453e92ccc01697f29bb5dbeb9'] = 'Options d\'importation ';
$_MODULE['<{shopImporter}prestashop>shopImporter_93cba07454f06a4a960172bbd6e2a435'] = 'Oui';
$_MODULE['<{shopImporter}prestashop>shopImporter_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Non';
$_MODULE['<{shopImporter}prestashop>shopImporter_f2a6c498fb90ee345d997f888fce3b18'] = 'Supprimer ';
$_MODULE['<{shopImporter}prestashop>shopImporter_9dfc5d5738312210c3c75e68a468691d'] = 'Options avancées ';
$_MODULE['<{shopImporter}prestashop>shopImporter_c195d4db1be0d349d21f236f0a6400ff'] = 'Ce mode est dangereux ';
$_MODULE['<{shopImporter}prestashop>shopImporter_1404aa04467659fbadad2a7dd1a279b3'] = 'Si des erreurs se produisent ';
$_MODULE['<{shopImporter}prestashop>shopImporter_11a755d598c0c417f9a36758c3da7481'] = 'Stop';
$_MODULE['<{shopImporter}prestashop>shopImporter_72ef2b9b6965d078e3c7f95487a82d1c'] = 'Passer';
$_MODULE['<{shopImporter}prestashop>shopImporter_9eb6b78a99cdb6ffd3d40d18621d9f80'] = 'Forcer';
$_MODULE['<{shopImporter}prestashop>shopImporter_3ba85f1eb1b88c1bab7f0e5f2f4b1b90'] = 'Stop : s\'il ya des erreurs dans l\'audit des données, l\'importation ne fonctionne pas. ';
$_MODULE['<{shopImporter}prestashop>shopImporter_02ec2f594c13f3ee94dfc7ebdb424da6'] = 'Passer : s\'il ya des erreurs dans l\'audit des données d\'audit, l\'importation va sauter des données incorrectes.';
$_MODULE['<{shopImporter}prestashop>shopImporter_d82122d9c0946c1f293a457888122b5e'] = 'Forcer : s\'il ya des erreurs dans l\'audit des données,, l\'importation des données incorrectes remplacer par des données génériques.';
$_MODULE['<{shopImporter}prestashop>shopImporter_09b4382d10c396e0c4fcd51064702213'] = 'Options spécifiques ';
$_MODULE['<{shopImporter}prestashop>shopImporter_01f8544c8fd4628bc686502e8b727d95'] = 'le champ';
$_MODULE['<{shopImporter}prestashop>shopImporter_0a5fa53f3f20f67f98bd6c3b16df059d'] = 'est requit';
$_MODULE['<{shopImporter}prestashop>shopImporter_f755e8b92cb8f02c24f6f539180d45b1'] = 'est trop long';
$_MODULE['<{shopImporter}prestashop>shopImporter_70f4b635847038d056e33959821a7a66'] = 'caractères max ';
$_MODULE['<{shopImporter}prestashop>shopImporter_998b344cff693ad388a14ba89b1523c7'] = 'est invalide';
$_MODULE['<{shopImporter}prestashop>shopImporter_7e47a344b06d82a8836cbee2748a79e6'] = 'est exigée au moins dans ';

==> prestashop_1.4.0.9.zip: prestashop/modules/shopImporter/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{shopImporter}prestashop>shopImporter_d714c742b360a8ecbb124c15e9a391a1'] = 'Importateur de boutique';
$_MODULE['<{shopImporter}prestashop>shopImporter_b51e3d770566c831063a131631e494c2'] = 'Ce module permet d\'importer d\'un autre système dans prestashop';
$_MODULE['<{shopImporter}prestashop>shopImporter_4994a8ffeba4ac3140beb89e8d41f174'] = 'Langue';
$_MODULE['<{shopImporter}prestashop>shopImporter_a9db6adcdafc85c5830439401fd866f6'] = 'Importation des langues';
$_MODULE['<{shopImporter}prestashop>shopImporter_5c9ada346bd1c8b1adae50aec0e7437c'] = 'Les nouvelles langues seront automatiquement ajouter les traductions!';
$_MODULE['<{shopImporter}prestashop>shopImporter_386c339d37e737a436499d423a77df0c'] = 'Devise';
$_MODULE['<{shopImporter}prestashop>shopImporter_4234c64201820401dfa04eeb449c1bbc'] = 'Importation des Devises';
$_MODULE['<{shopImporter}prestashop>shopImporter_b3ff996fe5c77610359114835baf9b38'] = 'Zone';
$_MODULE['<{shopImporter}prestashop>shopImporter_21d250d17e35e3e02db9f1a618bad913'] = 'Importation des Zones';
$_MODULE['<{shopImporter}prestashop>shopImporter_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{shopImporter}prestashop>shopImporter_13eedcf49d68ce49274db71e63a7aa3d'] = 'Importation des Pays';
$_MODULE['<{shopImporter}prestashop>shopImporter_46a2a41cc6e552044816a2d04634545d'] = 'Etat';
$_MODULE['<{shopImporter}prestashop>shopImporter_118421de3201927a23bf921057e69c4a'] = 'Importation des Etats';
$_MODULE['<{shopImporter}prestashop>shopImporter_03937134cedab9078be39a77ee3a48a0'] = 'Groupe';
$_MODULE['<{shopImporter}prestashop>shopImporter_65ac19ad248219902394739bda0cef62'] = 'Importation des Groupes';
$_MODULE['<{shopImporter}prestashop>shopImporter_ce26601dac0dea138b7295f02b7620a7'] = 'Client';
$_MODULE['<{shopImporter}prestashop>shopImporter_22c34564e80ce8adab6a235061d277f4'] = 'Importation des Clients';
$_MODULE['<{shopImporter}prestashop>shopImporter_dd7bf230fde8d4836917806aff6a6b27'] = 'Adresse';
$_MODULE['<{shopImporter}prestashop>shopImporter_77497d022aeb4cdd78ec394ca8d223b4'] = 'Importation des Adresses';
$_MODULE['<{shopImporter}prestashop>shopImporter_a240fa27925a635b08dc28c9e4f9216d'] = 'Commande';
$_MODULE['<{shopImporter}prestashop>shopImporter_3b7e768ebab2171baa41d5ea13017b02'] = 'Importation des Commandes';
$_MODULE['<{shopImporter}prestashop>shopImporter_c0bd7654d5b278e65f21cf4e9153fdb4'] = 'Fabricant';
$_MODULE['<{shopImporter}prestashop>shopImporter_ed4cbbbeb3d575ccfeb405ae5c5c4d43'] = 'Importation des Fabricants';
$_MODULE['<{shopImporter}prestashop>shopImporter_ec136b444eede3bc85639fac0dd06229'] = 'Fournisseur';
$_MODULE['<{shopImporter}prestashop>shopImporter_0ae5f9c75e6a7460ec31e33201576bd9'] = 'Importation des Fournisseurs';
$_MODULE['<{shopImporter}prestashop>shopImporter_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Categorie';
$_MODULE['<{shopImporter}prestashop>shopImporter_1db7ae20c24e257b6f1a7def365da1ad'] = 'Importation des Categories';
$_MODULE['<{shopImporter}prestashop>shopImporter_deb10517653c255364175796ace3553f'] = 'Produit';
$_MODULE['<{shopImporter}prestashop>shopImporter_4bfc4a7632bae0877b798dbd9efc4f70'] = 'Importation des Produits';
$_MODULE['<{shopImporter}prestashop>shopImporter_d6dd5b5b36770c26db3e12c02c2a37db'] = 'Déclinaisons de Produits';
$_MODULE['<{shopImporter}prestashop>shopImporter_58e2fcec5e04716c627b3e8b9d2955b1'] = 'Importation des Déclinaisons de Produits';
$_MODULE['<{shopImporter}prestashop>shopImporter_32a6deec3cca312a54d6b8769c9b8dd7'] = 'n\'est pas disponible dans ce module';
$_MODULE['<{shopImporter}prestashop>shopImporter_1e411d25230ba738b9ae583bcb9b0b57'] = 'Connexion à la base OK';
$_MODULE['<{shopImporter}prestashop>shopImporter_3596c777cbc8b72d678f34daabc9148b'] = 'Voir les erreurs';
$_MODULE['<{shopImporter}prestashop>shopImporter_89a399eee52b2a6daaea92eba3e14cad'] = 'Lancer le test d\'import';
$_MODULE['<{shopImporter}prestashop>shopImporter_72d6d7a1885885bb55a565fd1070581a'] = 'Importer';
$_MODULE['<{shopImporter}prestashop>shopImporter_e08d2dad1fcd8a0d89e242939b2475bb'] = 'Merci de corriger les erreurs avant de continuer';
$_MODULE['<{shopImporter}prestashop>shopImporter_a4376f284662da6f3997514ca74597c9'] = 'L\'import est terminé';
$_MODULE['<{shopImporter}prestashop>shopImporter_596403b61367ca30d6de75812275f9cd'] = 'Suppression des données';
$_MODULE['<{shopImporter}prestashop>shopImporter_edc186cbc5cc897a79312880ec16c621'] = 'Merci de choisir quelquechose à importer';
$_MODULE['<{shopImporter}prestashop>shopImporter_81b33153f65252001fe132d74b658fbe'] = 'Importer à partir d\'un autre système ';
$_MODULE['<{shopImporter}prestashop>shopImporter_dd4c0c798ebbf8c6e15dcba8632f558d'] = 'Avant de commencer l\'importation merci de sauvegarder votre base de données.';
$_MODULE['<{shopImporter}prestashop>shopImporter_60474e812295a5adc371de63dc62a164'] = 'Cliquez ici pour sauvegarder';
$_MODULE['<{shopImporter}prestashop>shopImporter_05f4be265d59ea66f3a1fb12ba103583'] = 'Choisissez votre module d\'importation  ';
$_MODULE['<{shopImporter}prestashop>shopImporter_961f2247a2070bedff9f9cd8d64e2650'] = 'Choisir';
$_MODULE['<{shopImporter}prestashop>shopImporter_9aa1b03934893d7134a660af4204f2a9'] = 'Serveur';
$_MODULE['<{shopImporter}prestashop>shopImporter_8f9bfe9d1345237cb3b2b205864da075'] = 'Utilisateur';
$_MODULE['<{shopImporter}prestashop>shopImporter_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{shopImporter}prestashop>shopImporter_e307db07b3975fef922a80d07455ee5e'] = 'Base de données';
$_MODULE['<{shopImporter}prestashop>shopImporter_dac130bdd2c5492a8108a4145bd9f04a'] = 'Prefix de base de données';
$_MODULE['<{shopImporter}prestashop>shopImporter_2bb4cbbf4c51025867d47131e79ad05f'] = 'Étape suivante';
$_MODULE['<{shopImporter}prestashop>shopImporter_72dd98a453e92ccc01697f29bb5dbeb9'] = 'Options d\'importation ';
$_MODULE['<{shopImporter}prestashop>shopImporter_93cba07454f06a4a960172bbd6e2a435'] = 'Oui';
$_MODULE['<{shopImporter}prestashop>shopImporter_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Non';
$_MODULE['<{shopImporter}prestashop>shopImporter_f2a6c498fb90ee345d997f888fce3b18'] = 'Supprimer ';
$_MODULE['<{shopImporter}prestashop>shopImporter_9dfc5d5738312210c3c75e68a468691d'] = 'Options avancées ';
$_MODULE['<{shopImporter}prestashop>shopImporter_c195d4db1be0d349d21f236f0a6400ff'] = 'Ce mode est dangereux ';
$_MODULE['<{shopImporter}prestashop>shopImporter_1404aa04467659fbadad2a7dd1a279b3'] = 'Si des erreurs se produisent ';
$_MODULE['<{shopImporter}prestashop>shopImporter_11a755d598c0c417f9a36758c3da7481'] = 'Stop';
$_MODULE['<{shopImporter}prestashop>shopImporter_72ef2b9b6965d078e3c7f95487a82d1c'] = 'Passer';
$_MODULE['<{shopImporter}prestashop>shopImporter_9eb6b78a99cdb6ffd3d40d18621d9f80'] = 'Forcer';
$_MODULE['<{shopImporter}prestashop>shopImporter_05d2b3715ac0c697b86799d1989c4aeb'] = 'Stopper : si des erreurs se produisent à cause des données, l\'import ne se lancera pas';
$_MODULE['<{shopImporter}prestashop>shopImporter_690c3a7f595050729df99a6d30dd6f96'] = 'Stopper : si des erreurs se produisent à cause des données, l\'import ignorera ces dernières';
$_MODULE['<{shopImporter}prestashop>shopImporter_35a6535254a93c5338bff1e3572755d2'] = 'Forcer : si des erreurs se produisent à cause des données, l\'import remplacera les données incorrectes par des données génériques.';
$_MODULE['<{shopImporter}prestashop>shopImporter_09b4382d10c396e0c4fcd51064702213'] = 'Options spécifiques ';
$_MODULE['<{shopImporter}prestashop>shopImporter_01f8544c8fd4628bc686502e8b727d95'] = 'le champ';
$_MODULE['<{shopImporter}prestashop>shopImporter_0a5fa53f3f20f67f98bd6c3b16df059d'] = 'est requit';
$_MODULE['<{shopImporter}prestashop>shopImporter_f755e8b92cb8f02c24f6f539180d45b1'] = 'est trop long';
$_MODULE['<{shopImporter}prestashop>shopImporter_70f4b635847038d056e33959821a7a66'] = 'caractères max ';
$_MODULE['<{shopImporter}prestashop>shopImporter_998b344cff693ad388a14ba89b1523c7'] = 'est invalide';
$_MODULE['<{shopImporter}prestashop>shopImporter_7e47a344b06d82a8836cbee2748a79e6'] = 'est exigée au moins dans ';
